@@ -16,16 +16,24 @@ class Droplet(object):
         self.private_ip_address = None
         self.call_reponse = None
         self.ssh_key_ids = None
+        self.created_at = None
         self.events = []
 
         #Setting the attribute values
         for attr in kwargs.keys():
             setattr(self,attr,kwargs[attr])
 
+    def call_api(self, path, params=dict()):
+        """
+            exposes any api entry
+            useful when working with new API calls that are not yet implemented by Droplet class
+        """
+        return self.__call_api(path, params)
+
     def __call_api(self, path, params=dict()):
         payload = {'client_id': self.client_id, 'api_key': self.api_key}
         payload.update(params)
-        r = requests.get("https://api.digitalocean.com/droplets/%s%s" % ( self.id, path ), params=payload)
+        r = requests.get("https://api.digitalocean.com/v1/droplets/%s%s" % ( self.id, path ), params=payload)
         data = r.json()
         self.call_response = data
         if data['status'] != "OK":
@@ -49,6 +57,7 @@ class Droplet(object):
         self.name = droplet['name']
         self.ip_address = droplet['ip_address']
         self.private_ip_address = droplet['private_ip_address']
+        self.created_at = droplet['created_at']
         self.id = droplet['id']
 
     def power_on(self):
@@ -131,6 +140,12 @@ class Droplet(object):
         """
         self.__call_api("/destroy/", {'scrub_data': '1' if scrub_data else '0'})
 
+    def rename(self, name):
+        """
+            Rename the droplet
+        """
+        self.__call_api("/rename/", {'name': name})
+
     def create(self, ssh_key_ids=None, virtio=False, private_networking=False, backups_enabled=False):
         """
             Create the droplet with object properties.
