@@ -14,7 +14,7 @@ class Event(object):
     def __call_api(self, path, params=dict()):
         payload = {'client_id': self.client_id, 'api_key': self.api_key}
         payload.update(params)
-        r = requests.get("https://api.digitalocean.com/events/%s%s" % ( self.id, path ), params=payload)
+        r = requests.get("https://api.digitalocean.com/v1/events/%s%s" % ( self.id, path ), params=payload)
         data = r.json()
         self.call_response = data
         if data['status'] != "OK":            
@@ -31,4 +31,4 @@ class Event(object):
             self.percentage = event[u'percentage']
             self.droplet_id = event[u'droplet_id']
             self.action_status = event[u'action_status']
-        
\ No newline at end of file
+        
