@@ -12,7 +12,7 @@ class Image(object):
     def __call_api(self, path, params=dict()):
         payload = {'client_id': self.client_id, 'api_key': self.api_key}
         payload.update(params)
-        r = requests.get("https://api.digitalocean.com/images/%s%s" % ( self.id, path ), params=payload)
+        r = requests.get("https://api.digitalocean.com/v1/images/%s%s" % ( self.id, path ), params=payload)
         data = r.json()
         self.call_response = data
         if data['status'] != "OK":
