@@ -1,8 +1,8 @@
 
 """digitalocean API to manage droplets"""
 
-__version__ = "0.7"
-__author__ = "Lorenzo Setale ( http://who.is.koalalorenzo.com/? )"
+__version__ = "0.7.1"
+__author__ = "Lorenzo Setale ( http://who.is.lorenzo.setale.me/? )"
 __author_email__ = "koalalorenzo@gmail.com"
 __license__ = "See: http://creativecommons.org/licenses/by-nd/3.0/ "
 __copyright__ = "Copyright (c) 2012, 2013, 2014 Lorenzo Setale"
@@ -15,3 +15,4 @@ from .Image import Image
 from .Event import Event
 from .Domain import Domain
 from .Record import Record
+from .SSHKey import SSHKey
